# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`rustup::global`](#rustup--global): Manage global Rust installation with `rustup`

### Defined types

* [`rustup`](#rustup): Manage a user’s Rust installation with `rustup`
* [`rustup::exec`](#rustup--exec): Run a `rustup` command
* [`rustup::global::target`](#rustup--global--target): Install a target for a toolchain for global installation
* [`rustup::global::toolchain`](#rustup--global--toolchain): Install a toolchain for global installation
* [`rustup::target`](#rustup--target): Install a target for a toolchain
* [`rustup::toolchain`](#rustup--toolchain): Install a toolchain

### Resource types

#### Private Resource types

* `rustup_internal`: Manage a user’s Rust installation with `rustup`

### Functions

#### Private Functions

* `rustup::home`: Return the default home directory for a user on this OS

### Data types

* [`Rustup::OptionalStringOrArray`](#Rustup--OptionalStringOrArray): Convenience type to make params easier to read
* [`Rustup::Profile`](#Rustup--Profile): Profile for toolchain installation

## Classes

### <a name="rustup--global"></a>`rustup::global`

Manage global Rust installation with `rustup`

#### Examples

##### Standard usage

```puppet
include rustup::global
```

#### Parameters

The following parameters are available in the `rustup::global` class:

* [`ensure`](#-rustup--global--ensure)
* [`user`](#-rustup--global--user)
* [`manage_user`](#-rustup--global--manage_user)
* [`purge_toolchains`](#-rustup--global--purge_toolchains)
* [`purge_targets`](#-rustup--global--purge_targets)
* [`dist_server`](#-rustup--global--dist_server)
* [`home`](#-rustup--global--home)
* [`shell`](#-rustup--global--shell)
* [`env_scripts_append`](#-rustup--global--env_scripts_append)
* [`env_scripts_create`](#-rustup--global--env_scripts_create)
* [`installer_source`](#-rustup--global--installer_source)

##### <a name="-rustup--global--ensure"></a>`ensure`

Data type: `Enum[present, latest, absent]`

* `present` - install rustup, but don’t update it.
* `latest` - install rustup and update it on every puppet run.
* `absent` - uninstall rustup and the tools it manages.

Default value: `present`

##### <a name="-rustup--global--user"></a>`user`

Data type: `String[1]`

The user to own and manage rustup. We recommend not using root or any other
existing user.

Default value: `'rustup'`

##### <a name="-rustup--global--manage_user"></a>`manage_user`

Data type: `Boolean`

Whether or not to manage `$user` user.

Default value: `true`

##### <a name="-rustup--global--purge_toolchains"></a>`purge_toolchains`

Data type: `Boolean`

Whether or not to uninstall toolchains that aren’t managed by Puppet.

Default value: `false`

##### <a name="-rustup--global--purge_targets"></a>`purge_targets`

Data type: `Boolean`

Whether or not to uninstall targets that aren’t managed by Puppet.

Default value: `false`

##### <a name="-rustup--global--dist_server"></a>`dist_server`

Data type: `Optional[Stdlib::HTTPUrl]`

Override `RUSTUP_DIST_SERVER`. Set to `'https://dev-static.rust-lang.org'`
to install pre-release toolchains.

Default value: `undef`

##### <a name="-rustup--global--home"></a>`home`

Data type: `Stdlib::Absolutepath`

Where to install rustup and the rust toolchains. Will contain rustup and
cargo directories.

Default value: `'/opt/rust'`

##### <a name="-rustup--global--shell"></a>`shell`

Data type: `Stdlib::Absolutepath`

Shell for the rustup user. This can be a nologin shell.

Default value: `'/bin/bash'`

##### <a name="-rustup--global--env_scripts_append"></a>`env_scripts_append`

Data type: `Array[Stdlib::Absolutepath]`

Scripts to append with line that sources the cargo environment script.

Default value: `['/etc/bashrc']`

##### <a name="-rustup--global--env_scripts_create"></a>`env_scripts_create`

Data type: `Array[Stdlib::Absolutepath]`

Paths that will get links to the cargo environment script.

Default value: `['/etc/profile.d/99-cargo.sh']`

##### <a name="-rustup--global--installer_source"></a>`installer_source`

Data type: `Stdlib::HTTPUrl`

URL of the rustup installation script. Changing this will have no effect
after the initial installation.

Default value: `'https://sh.rustup.rs'`

## Defined types

### <a name="rustup"></a>`rustup`

The name should be the username.

#### Examples

##### Standard usage

```puppet
rustup { 'daniel': }
```

#### Parameters

The following parameters are available in the `rustup` defined type:

* [`ensure`](#-rustup--ensure)
* [`user`](#-rustup--user)
* [`default_toolchain`](#-rustup--default_toolchain)
* [`toolchains`](#-rustup--toolchains)
* [`purge_toolchains`](#-rustup--purge_toolchains)
* [`targets`](#-rustup--targets)
* [`purge_targets`](#-rustup--purge_targets)
* [`dist_server`](#-rustup--dist_server)
* [`home`](#-rustup--home)
* [`rustup_home`](#-rustup--rustup_home)
* [`cargo_home`](#-rustup--cargo_home)
* [`modify_path`](#-rustup--modify_path)
* [`installer_source`](#-rustup--installer_source)

##### <a name="-rustup--ensure"></a>`ensure`

Data type: `Enum[present, latest, absent]`

* `present` - install rustup, but don’t update it.
* `latest` - install rustup and update it on every puppet run.
* `absent` - uninstall rustup and the tools it manages.

Default value: `present`

##### <a name="-rustup--user"></a>`user`

Data type: `String[1]`

The user to own and manage rustup.

Default value: `$name`

##### <a name="-rustup--default_toolchain"></a>`default_toolchain`

Data type: `Optional[String[1]]`

Which toolchain should be the default.

Default value: `undef`

##### <a name="-rustup--toolchains"></a>`toolchains`

Data type: `Array[String[1]]`

The toolchains to install.

Default value: `[]`

##### <a name="-rustup--purge_toolchains"></a>`purge_toolchains`

Data type: `Boolean`

Whether or not to uninstall toolchains that aren’t managed by Puppet.

Default value: `false`

##### <a name="-rustup--targets"></a>`targets`

Data type: `Array[String[1]]`

The targets to install. These can take two forms:

  * `"$target $toolchain"`: Install `$target` for `$toolchain`.
  * `"$target"`: Install `$target` for the default toolchain.

You can use `'default'` to indicate the target for the current host.

Default value: `[]`

##### <a name="-rustup--purge_targets"></a>`purge_targets`

Data type: `Boolean`

Whether or not to uninstall targets that aren’t managed by Puppet.

Default value: `false`

##### <a name="-rustup--dist_server"></a>`dist_server`

Data type: `Optional[Stdlib::HTTPUrl]`

Override `RUSTUP_DIST_SERVER`. Set to `'https://dev-static.rust-lang.org'`
to install pre-release toolchains.

Default value: `undef`

##### <a name="-rustup--home"></a>`home`

Data type: `Stdlib::Absolutepath`

The user’s home directory. This defaults to `/home/$user` on Linux and
`/Users/$user` on macOS.

Default value: `rustup::home($user)`

##### <a name="-rustup--rustup_home"></a>`rustup_home`

Data type: `Stdlib::Absolutepath`

Where toolchains are installed. Generally you shouldn’t change this.

Default value: `"${home}/.rustup"`

##### <a name="-rustup--cargo_home"></a>`cargo_home`

Data type: `Stdlib::Absolutepath`

Where `cargo` installs executables. Generally you shouldn’t change this.

Default value: `"${home}/.cargo"`

##### <a name="-rustup--modify_path"></a>`modify_path`

Data type: `Boolean`

Whether or not to let `rustup` modify the user’s `PATH` in their shell init
scripts. This only affects the initial installation and removal.

Default value: `true`

##### <a name="-rustup--installer_source"></a>`installer_source`

Data type: `Stdlib::HTTPUrl`

URL of the rustup installation script. Changing this will have no effect
after the initial installation.

Default value: `'https://sh.rustup.rs'`

### <a name="rustup--exec"></a>`rustup::exec`

The name should start with the username followed by a colon and a space, then
the command. For example:

```puppet
rustup::exec { 'daniel: rustup default nightly': }
```

[`exec`]: https://puppet.com/docs/puppet/latest/types/exec.html

#### Parameters

The following parameters are available in the `rustup::exec` defined type:

* [`user`](#-rustup--exec--user)
* [`command`](#-rustup--exec--command)
* [`creates`](#-rustup--exec--creates)
* [`environment`](#-rustup--exec--environment)
* [`onlyif`](#-rustup--exec--onlyif)
* [`refreshonly`](#-rustup--exec--refreshonly)
* [`unless`](#-rustup--exec--unless)
* [`home`](#-rustup--exec--home)
* [`rustup_home`](#-rustup--exec--rustup_home)
* [`cargo_home`](#-rustup--exec--cargo_home)
* [`bin`](#-rustup--exec--bin)
* [`more`](#-rustup--exec--more)

##### <a name="-rustup--exec--user"></a>`user`

Data type: `String[1]`

The user to run as. Automatically set if the `$name` of the resource follows
the rules above.

Default value: `$name.split(': ')[0]`

##### <a name="-rustup--exec--command"></a>`command`

Data type: `String[1]`

The command to run, e.g. 'rustup default stable'. Automatically set if the
`$name` of the resource follows the rules above.

Default value: `$name.split(': ')[1]`

##### <a name="-rustup--exec--creates"></a>`creates`

Data type: `Optional[String[1]]`

Only run when if this path does not exist. (See [`exec`] documentation.)

Default value: `undef`

##### <a name="-rustup--exec--environment"></a>`environment`

Data type: `Array[String[1]]`

Additional environment variables to set beyond `RUSTUP_HOME`, `CARGO_HOME`,
and `PATH`.

Default value: `[]`

##### <a name="-rustup--exec--onlyif"></a>`onlyif`

Data type: `Rustup::OptionalStringOrArray`

Only run when `$onlyif` returns success. (See [`exec`] documentation.)

Default value: `undef`

##### <a name="-rustup--exec--refreshonly"></a>`refreshonly`

Data type: `Boolean`

Only run this when it receives an event. (See [`exec`] documentation.)

Default value: `false`

##### <a name="-rustup--exec--unless"></a>`unless`

Data type: `Rustup::OptionalStringOrArray`

Only run when `$unless` returns failure. (See [`exec`] documentation.)

Default value: `undef`

##### <a name="-rustup--exec--home"></a>`home`

Data type: `Stdlib::Absolutepath`

The user’s home directory. This defaults to `/home/$user` on Linux and
`/Users/$user` on macOS. This is only used to calculate defaults for the
`$rustup_home` and `$cargo_home` parameters.

Default value: `rustup::home($user)`

##### <a name="-rustup--exec--rustup_home"></a>`rustup_home`

Data type: `Stdlib::Absolutepath`

Where toolchains are installed. Generally you shouldn’t change this.

Default value: `"${home}/.rustup"`

##### <a name="-rustup--exec--cargo_home"></a>`cargo_home`

Data type: `Stdlib::Absolutepath`

Where `cargo` installs executables. Generally you shouldn’t change this.

Default value: `"${home}/.cargo"`

##### <a name="-rustup--exec--bin"></a>`bin`

Data type: `Stdlib::Absolutepath`

Where `rustup` installs proxy executables. Generally you shouldn’t change
this.

Default value: `"${cargo_home}/bin"`

##### <a name="-rustup--exec--more"></a>`more`

Data type: `Hash[String[1], Any]`

Other parameters to pass to exec. They may override any of the other
parameters.

Default value: `{}`

### <a name="rustup--global--target"></a>`rustup::global::target`

You can name this two ways to automatically set the parameters:

  * `"$target $toolchain"`: install `$target` for `$toolchain` in the global
    installation. For example, `'x86_64-unknown-linux-gnu nightly'`.
  * `"$target"`: install `$target` for the default toolchain in the global
    installation. For example: `'stable'`.

#### Parameters

The following parameters are available in the `rustup::global::target` defined type:

* [`ensure`](#-rustup--global--target--ensure)
* [`target`](#-rustup--global--target--target)
* [`toolchain`](#-rustup--global--target--toolchain)

##### <a name="-rustup--global--target--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the target should be present or absent.

Default value: `present`

##### <a name="-rustup--global--target--target"></a>`target`

Data type: `String[1]`

The name of the target to install, e.g. "sparcv9-sun-solaris". Automatically
set if the `$name` of the resource follows the rules above.

Default value: `$name.split(' ')[0]`

##### <a name="-rustup--global--target--toolchain"></a>`toolchain`

Data type: `Optional[String[1]]`

The name of the toolchain in which to install the target, e.g. "stable".
`undef` means the default toolchain. Automatically set if the `$name` of the
resource follows the rules above.

Default value: `$name.split(' ')[1]`

### <a name="rustup--global--toolchain"></a>`rustup::global::toolchain`

The name should just be the toolchain. For example:

```puppet
rustup::global::toolchain { 'stable': }
```

#### Parameters

The following parameters are available in the `rustup::global::toolchain` defined type:

* [`ensure`](#-rustup--global--toolchain--ensure)
* [`toolchain`](#-rustup--global--toolchain--toolchain)
* [`profile`](#-rustup--global--toolchain--profile)

##### <a name="-rustup--global--toolchain--ensure"></a>`ensure`

Data type: `Enum[present, latest, absent]`

* `present` - install toolchain if it doesn’t exist, but don’t update it.
* `latest` - install toolchain and update it on every puppet run.
* `absent` - uninstall toolchain.

Default value: `present`

##### <a name="-rustup--global--toolchain--toolchain"></a>`toolchain`

Data type: `String[1]`

The name of the toolchain to install, e.g. "stable".

Default value: `$name`

##### <a name="-rustup--global--toolchain--profile"></a>`profile`

Data type: `Rustup::Profile`

Profile to use for installation. This determines which components will be
installed initially.

Changing this for an existing installation will not have an effect even if
it causes an update, i.e. when `ensure => latest` is set.

Default value: `'default'`

### <a name="rustup--target"></a>`rustup::target`

You can name this two ways to automatically set the parameters:

  * `"$rustup: $target $toolchain"`: install `$target` for `$toolchain` for
    the `rustup` resource named `$rustup` (normally the username). For
    example, `'daniel: x86_64-unknown-linux-gnu nightly'`.
  * `"$rustup: $target"`: install `$target` for the default toolchain for
    the `rustup` resource named `$rustup` (normally the username). For
    example: `'daniel: stable'`.

You may use the string `'default'` as the target to indicate the target that
corresponds to the current host.

#### Parameters

The following parameters are available in the `rustup::target` defined type:

* [`ensure`](#-rustup--target--ensure)
* [`rustup`](#-rustup--target--rustup)
* [`target`](#-rustup--target--target)
* [`toolchain`](#-rustup--target--toolchain)

##### <a name="-rustup--target--ensure"></a>`ensure`

Data type: `Enum[present, absent]`

Whether the target should be present or absent.

Default value: `present`

##### <a name="-rustup--target--rustup"></a>`rustup`

Data type: `String[1]`

The name of the `rustup` installation (normally the username). Automatically
set if the `$name` of the resource follows the rules above.

Default value: `$name.split(': ')[0]`

##### <a name="-rustup--target--target"></a>`target`

Data type: `String[1]`

The name of the target to install, e.g. "sparcv9-sun-solaris". Automatically
set if the `$name` of the resource follows the rules above.

Default value: `$name.split(': ')[1].split(' ')[0]`

##### <a name="-rustup--target--toolchain"></a>`toolchain`

Data type: `Optional[String[1]]`

The name of the toolchain in which to install the target, e.g. "stable".
`undef` means the default toolchain. Automatically set if the `$name` of the
resource follows the rules above.

Default value: `$name.split(': ')[1].split(' ')[1]`

### <a name="rustup--toolchain"></a>`rustup::toolchain`

The name should start with the name of the `rustup` resource (normally the
name of the user) followed by a colon and a space, then the toolchain. For
example:

```puppet
rustup::toolchain { 'daniel: stable': }
```

#### Parameters

The following parameters are available in the `rustup::toolchain` defined type:

* [`ensure`](#-rustup--toolchain--ensure)
* [`rustup`](#-rustup--toolchain--rustup)
* [`toolchain`](#-rustup--toolchain--toolchain)
* [`profile`](#-rustup--toolchain--profile)

##### <a name="-rustup--toolchain--ensure"></a>`ensure`

Data type: `Enum[present, latest, absent]`

* `present` - install toolchain if it doesn’t exist, but don’t update it.
* `latest` - install toolchain and update it on every puppet run.
* `absent` - uninstall toolchain.

Default value: `present`

##### <a name="-rustup--toolchain--rustup"></a>`rustup`

Data type: `String[1]`

The name of the `rustup` installation (normally the username). Automatically
set if the `$name` of the resource follows the rules above.

Default value: `$name.split(': ')[0]`

##### <a name="-rustup--toolchain--toolchain"></a>`toolchain`

Data type: `String[1]`

The name of the toolchain to install, e.g. "stable". Automatically set if
the `$name` of the resource follows the rules above.

Default value: `$name.split(': ')[1]`

##### <a name="-rustup--toolchain--profile"></a>`profile`

Data type: `Rustup::Profile`

Profile to use for installation. This determines which components will be
installed initially.

Changing this for an existing installation will not have an effect even if
it causes an update, i.e. when `ensure => latest` is set.

Default value: `'default'`

## Data types

### <a name="Rustup--OptionalStringOrArray"></a>`Rustup::OptionalStringOrArray`

Convenience type to make params easier to read

Alias of `Variant[Undef, String[1], Array[String[1]]]`

### <a name="Rustup--Profile"></a>`Rustup::Profile`

`default` is a keyword in Puppet, so it must always be wrapped in quotes.

Alias of `Enum[minimal, 'default', complete]`

